#!/usr/bin/perl
#    Original VB script: 
#    Copyright (C) 2009 Ian Richardson, Murray Thomson
#    CREST (Centre for Renewable Energy Systems Technology),
#    Department of Electronic and Electrical Engineering
#    Loughborough University, Leicestershire LE11 3TU, UK
#    Tel. +44 1509 635326. Email address: I.W.Richardson2@lboro.ac.uk

#    Perl implementation:
#    Copyright (C) 2010 Gergely Acs <acs@crysys.hu>

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.


package LightConfig;
use strict;
use accessors qw( GlobalIrrMean GlobalIrrStdDev CalibrationScalar );
use vars qw($VERSION);
$VERSION = '0.01';

my @eff_occ;
my @duration;

sub new 
{
	my $package = shift;
	@eff_occ = ();
	@duration = ();
	return bless({}, $package);
}

sub LoadFromFile
{
	my $self = shift;

	die("Unable to open $_[0]!\n") unless open (IN, $_[0]);

	while (<IN>)
	{
		my @item = split /[,\n]/;

		if ($item[0] eq "House external global irradiance threshold")
		{
			$self->GlobalIrrMean($item[1]);
			$self->GlobalIrrStdDev($item[2]);
		}
		elsif ($item[0] eq "Calibration scalar")
		{
			$self->CalibrationScalar($item[1]);
		}
		elsif ($item[0] eq "Effective occupancy")
		{
			$eff_occ[$item[1]] = $item[2];
		}
		elsif ($item[0] eq "Lighting event duration model")
		{
			$duration[$item[1]][0] = $item[2];
			$duration[$item[1]][1] = $item[3];
			$duration[$item[1]][2] = $item[4];
		}
	}
	
	close IN;
}

sub GetEffectiveOccupancy
{
	shift;
	return $eff_occ[$_[0]]; 
}

sub GetLowerCumProb
{
	shift;
	return $duration[$_[0]][2];
}

sub GetLowerMin
{
	shift;
	return $duration[$_[0]][0];
}

sub GetUpperMin
{
	shift;
	return $duration[$_[0]][1];
}

1;
