#!/usr/bin/perl
#    Original VB script: 
#    Copyright (C) 2009 Ian Richardson, Murray Thomson
#    CREST (Centre for Renewable Energy Systems Technology),
#    Department of Electronic and Electrical Engineering
#    Loughborough University, Leicestershire LE11 3TU, UK
#    Tel. +44 1509 635326. Email address: I.W.Richardson2@lboro.ac.uk

#    Perl implementation:
#    Copyright (C) 2010 Gergely Acs <acs@crysys.hu>

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.


package LightSimData;
use Chart::Graph::Gnuplot qw(&gnuplot);
use strict;
use accessors qw( GlobalIrr HouseNum BulbsNum SimulationArray );
use vars qw($VERSION);
use List::Util 'sum';
$VERSION = '0.01';

sub new 
{
	my $package = shift;
	return bless({}, $package);
}

sub WriteToFile
{
	my $self = shift;

	my $filename = $_[0];

	die("Unable to open $_[0]!") unless open (OUT, ">" . $filename);

	my @arr = @{$self->SimulationArray};

	$" = ',';
	for (my $i = 0; $i < scalar(@arr); $i++)
	{
		print OUT ($i > 2 ? $i-2 : ''),",", ($i > 2 ? List::Util::sum(@{$arr[$i]}) : 
				($i == 0 ? "Sum" : '')) . ",@{$arr[$i]}\n"; 
	}

	close OUT;
}

sub GetPowerOnTime
{
	my $self = shift;
	my @arr = @{$self->SimulationArray};
	my @ret;

	for (my $i = 3; $i < scalar(@arr); $i++)
	{
		push @ret, List::Util::sum(@{$arr[$i]});
	}

	return @ret;
}

sub MakePlot
{
	my $self = shift;
	my ($filename, $title) = @_;

	my @seconds = map {$_ * 60} (0..1439);
	my @lighting_consumption = $self->GetPowerOnTime();

	gnuplot({'title' => $title,
			'output type' => 'eps',
			'output file' => $filename,
			'xdata' => 'time',
			'timefmt' => '%s',
			'format' => ['x', '%H:%M'],
			'x-axis label' => 'Time',
			'y-axis label' => 'Power (W)',
			'extra_opts' => 'set nokey' },
			[{'type' => 'columns', 'style' => 'lines'}, \@seconds, \@lighting_consumption ] );
}


1;
