#!/usr/bin/perl
#    Original VB script: 
#    Copyright (C) 2009 Ian Richardson, Murray Thomson
#    CREST (Centre for Renewable Energy Systems Technology),
#    Department of Electronic and Electrical Engineering
#    Loughborough University, Leicestershire LE11 3TU, UK
#    Tel. +44 1509 635326. Email address: I.W.Richardson2@lboro.ac.uk

#    Perl implementation:
#    Copyright (C) 2010 Gergely Acs <acs@crysys.hu>

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.


package OccSimData;
use Chart::Graph::Gnuplot qw(&gnuplot);
use strict;
use accessors qw(  );
use vars qw($VERSION);
$VERSION = '0.01';

my @sim_data;

sub new 
{
	my $package = shift;
	@sim_data = ();
	return bless({}, $package);
}

sub GetActiveOccupants
{
	shift;

	my ($time) = @_;

	return $sim_data[$time];
}

sub SetActiveOccupants
{
	shift;

	my ($time, $value) = @_;

	$sim_data[$time] = $value;
}

sub GetData 
{
	return @sim_data;
}

sub WriteToFile
{
	shift;

	my $filename = $_[0];

	die("Unable to open $_[0]!") unless open (OUT, ">" . $filename);

	for (my $i = 0; $i < scalar(@sim_data); $i++)
	{
		print OUT ($i+1),",", $sim_data[$i], "\n"; 
	}

	close OUT;
}

sub MakePlot
{
	my $self = shift;
	my ($filename, $title) = @_;

	my @seconds = map {$_ * 600} (0..143);

	gnuplot({'title' => $title,
				'output type' => 'eps',
				'output file' => $filename,
				'xdata' => 'time',
				'timefmt' => '%s',
				'format' => ['x', '%H:%M'],
				'x-axis label' => 'Time',
				'y-axis label' => 'Number of active occupants',
				'extra_opts' => 'set nokey' },
				[{'type' => 'columns', 'style' => 'lines'}, \@seconds, \@sim_data ] );
}

1;
