#    Domestic Active Occupancy Model - Simulation Example Code
#    Original VB script: 
#    Copyright (C) 2009 Ian Richardson, Murray Thomson
#    CREST (Centre for Renewable Energy Systems Technology),
#    Department of Electronic and Electrical Engineering
#    Loughborough University, Leicestershire LE11 3TU, UK
#    Tel. +44 1509 635326. Email address: I.W.Richardson2@lboro.ac.uk

#    Perl implementation:
#    Copyright (C) 2010 Gergely Acs <acs@crysys.hu>

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.


package OccupancyModel;
use strict;
use vars qw($VERSION);
$VERSION = '0.01';

sub new 
{
	my $package = shift;
	return bless({}, $package);
}

sub RunOccupancySimulation
{
#
# RunOccupancySimulation Macro - This macro runs a single day active occupancy simulation
#
    shift;

    my ($iResidents, $bWeekend,  $occ_start_states, $occ_states, $occ_sim_data) = @_;
    # Declare variables
   # my $sCell; # A variable used to store the value in a cell
   # my $iResidents; # The number of residents of the house
  #  my $bWeekend; # A flag to determine if a weekend run is required
    #my $iTimeStep; # A loop count variable
   # my $fCumulativeP; # A varible to store a cumulative probability
  #  my $iCurrentState; # The current number of active occupants
   # my $sCol; # A variable to store a column reference
   # my $iRow;  # Variable to store the row to access in the TPM
    
    # Step 1: Get the input variables
    
    # Perform a range check on the input resident count
    
    # Perform a range check on the weekday/weekend flag
    #$bWeekend = $_[1] eq "wd";
    #die "Please specify either a weekday (wd) or a weekend (we.)" unless  ($_[1] eq "wd" || $_[1] eq "we");
    
    # Step 2: Determine the active occupancy start state between 00:00 and 00:10
    
    # Initialise the random number generator
    #Randomize
    
    # Determine the letter of the column from the Start States worksheet
    #$sCol = "#occ_start_states'!" + Left(Cells(2, 1 + iResidents).Address(True, False, xlA1), 1)
    
    # Pick a random number to determine the start state
    
    # Reset the cumulative probability count
    my $fCumulativeP = 0;
    my $fRand = rand();
    my $iCurrentState;
    
# Determine the start state at time 00:00 by checking the random number against the distribution
    for ($iCurrentState = 0;  $iCurrentState < 7; $iCurrentState++)
    {
# Add the probability for this number of active occupants
	    $fCumulativeP += $occ_start_states->GetProb($iResidents, $iCurrentState, $bWeekend);
	    #Range(sCol + CStr($iCurrentState + 12 + IIf(bWeekend, 11, 0))).Value

		    if ($fRand < $fCumulativeP)
		    {
# This is the start state
			   # Range("#occ_sim_data'!C11").Value = iCurrentState;
			    $occ_sim_data->SetActiveOccupants(0, $iCurrentState);
			    last;
		    }
    }
    
    # Step 3: Determine the active occupancy transitions for each ten minute period of the day

    # Now work out the transition steps
    for (my $iTimeStep = 1; $iTimeStep < 144; $iTimeStep++)
    {
        # Reset the cumulative probability count
        $fCumulativeP = 0;
        
        # Determine the row for this state
        #$iRow = (($iTimeStep - 1) * 7) + $iCurrentState + 11;

	$fRand = rand();
    
        # Define a loop count variable
        # Cycle through the probabilities for this state
        for( my $i = 0; $i < 7; $i++)
	{
            # Get the column reference
            #$sCol = Left(Cells(1, i + 3).Address(True, False, xlA1), 1)
                       
            # Add this probability
            #$fCumulativeP = $fCumulativeP + Range("#tpm" + CStr(iResidents) + "_" + IIf(bWeekend, "we", "wd") + "'!" + sCol + CStr(iRow)).Value
	    $fCumulativeP += $occ_states->GetProb($iTimeStep-1, $iCurrentState, $i, $bWeekend);
                       
            # See if this is a state transition
            if ($fRand < $fCumulativeP)
	    {
                # Transition to another or same state
                $iCurrentState = $i;
		last;
	    }
	}
        
	# Store the next state
	#Range("#occ_sim_data'!C" + CStr(iTimeStep + 11)).Value = $iCurrentState;
	$occ_sim_data->SetActiveOccupants($iTimeStep, $iCurrentState);
    }
}

1;
    
  












